****************
Charlotte_DB SDK
****************
An easy-to-use lighting fast SDK for a lighting fast DB.

Visit the repo's Wiki here for the documentation `here <https://github.com/Danlobaton/Charlotte_DB_SDK/wiki>`_

You can read and check out what Charlotte_DB is about in our `site <https://www.charlottedb.com/>`_

Enjoy (:

-Dany L and the Charlotte.AI team
dany@charlotteai.co

PS: To ge a key ahead over to charlottedb.online

